@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: snap-core
-version: 0.5.3.1
-id: snap-core-0.5.3.1-998d67849801009f39c366b7d57e08cd
+version: 0.7.0.1
+id: snap-core-0.7.0.1-c9c4fa906b76346c886d3577399c47b6
 
 license: BSD3
 copyright:
@@ -32,7 +32,7 @@ description: Snap is a simple and fast web development framework and server writ
              * Early termination of the computation if you know early what you want
              to return and want to prevent further monadic processing
              .
-             /Quick start/: The '\''Snap'\'' monad and HTTP definitions are in "Snap.Types",
+             /Quick start/: The '\''Snap'\'' monad and HTTP definitions are in "Snap.Core",
              some iteratee utilities are in "Snap.Iteratee".
              .
              Higher-level facilities for building web applications (like user/session
@@ -43,29 +43,35 @@ description: Snap is a simple and fast web development framework and server writ
              as Java servlets, or
              .
              * are interested in contributing to the Snap Framework project.
-category: Web
+category: Web, Snap
 author: James Sanders, Shu-yu Guo, Gregory Collins, Doug Beardsley
 pkgpath: www/hs-snap-core
 exposed: True
-exposed-modules: Snap.Types Snap.Iteratee Snap.Internal.Debug
-                 Snap.Internal.Http.Types Snap.Internal.Iteratee.Debug
-                 Snap.Internal.Parsing Snap.Util.FileServe Snap.Util.FileUploads
+exposed-modules: Snap.Core Snap.Types Snap.Iteratee
+                 Snap.Internal.Debug Snap.Internal.Http.Types
+                 Snap.Internal.Iteratee.Debug Snap.Internal.Parsing Snap.Test
+                 Snap.Types.Headers Snap.Util.FileServe Snap.Util.FileUploads
                  Snap.Util.GZip Snap.Util.Readable
 hidden-modules: Snap.Internal.Instances
-                Snap.Internal.Iteratee.BoyerMooreHorspool Snap.Internal.Routing
-                Snap.Internal.Types
-import-dirs: /usr/local/lib/ghc/snap-core-0.5.3.1
-library-dirs: /usr/local/lib/ghc/snap-core-0.5.3.1
-hs-libraries: HSsnap-core-0.5.3.1
+                Snap.Internal.Iteratee.BoyerMooreHorspool
+                Snap.Internal.Parsing.FastSet Snap.Internal.Routing
+                Snap.Internal.Types Snap.Internal.Test.RequestBuilder
+                Snap.Internal.Test.Assertions
+import-dirs: /usr/local/lib/ghc/snap-core-0.7.0.1
+library-dirs: /usr/local/lib/ghc/snap-core-0.7.0.1
+hs-libraries: HSsnap-core-0.7.0.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: MonadCatchIO-transformers-0.2.2.0-21f55e3743ac58803f508355a9eecc56
-         attoparsec-0.8.6.1-0be93c0db37da3d9d9d5934e440ceea4
-         attoparsec-enumerator-0.2.0.3-5c479f5651a8203b081194e7d5dda58a
+depends: HUnit-1.2.4.2-be0344577c1a02dafa135a046cdc2b0a
+         MonadCatchIO-transformers-0.2.2.0-21f55e3743ac58803f508355a9eecc56
+         attoparsec-0.10.1.0-fbbd15f07775c506a88ff9688f1e3d80
+         attoparsec-enumerator-0.3-2afb5d54bc9047b23fdc4c1e78b8a455
          base-4.3.1.0-ee15f259a627d341af7c80a17e8b0e66
+         base16-bytestring-0.1.1.4-fc3418da5942b5f8a0336a438f444ade
          blaze-builder-0.2.1.4-bfcede572046050679f95fe80b55244e
+         blaze-builder-enumerator-0.2.0.2-df798c5d3b66b7d31ad271ee40fdfe82
          bytestring-0.9.1.10-4e62762ee9b2a5d0cc5bc2fbaaeefd53
          bytestring-nums-0.3.2-963561c5ca3aa36f42500414fb3aea1c
          case-insensitive-0.3.0.1-4af9524f4c290b81b29e4dcfd15ad577
@@ -76,19 +82,22 @@ depends: MonadCatchIO-transformers-0.2.2.0-21f55e3743ac58803f508355a9eecc56
          enumerator-0.4.14-63fedf341c69a69125c64fd58230de7c
          filepath-1.2.0.0-956a4b0c127b8c317f6cac3946b0b803
          mtl-2.0.1.0-3e464329054b7660133198d73c31aca5
+         mwc-random-0.10.0.1-5ab65106530b9d3c515ef9f74f3549b6
          old-locale-1.0.0.2-25ff1e5e0486bb3cf2cb85cb7daf8f22
          old-time-1.0.0.6-249d424df19da9487f0cb7da3ccb0868
+         regex-posix-0.95.1-a9e39e4e2b85417b19bbafc0025a2e17
          text-0.11.1.5-a9f0a532672121c1439a824b6891e297
          time-1.2.0.3-ad46a3ade48e0011608895f44cc02a52
          transformers-0.2.2.0-89265f646be3aed4f502cfc5eccd7c93
          unix-compat-0.2-95c69a4141f1f166fd9d504e2e3aa283
+         unordered-containers-0.1.4.6-28f747c4016e8770374d58e8048fd160
          vector-0.7.1-3cb4afeb6b20e182ed5daf2f17289745
-         zlib-0.5.3.1-3c6d04702765b68fe92c99674060e068
+         zlib-enum-0.2.1-2c342e1a958924076ad5f23d043f1bb7
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-snap-core-0.5.3.1/html/snap-core.haddock
-haddock-html: /usr/local/share/doc/hs-snap-core-0.5.3.1/html
+haddock-interfaces: /usr/local/share/doc/hs-snap-core-0.7.0.1/html/snap-core.haddock
+haddock-html: /usr/local/share/doc/hs-snap-core-0.7.0.1/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
